==> hoteldruid-mod-fr_2.3.1-1.tar.gz: fr/modi_boo.php <==
<?php

switch ($messaggio) {

case "Hotel di Booking.com":  			$messaggio = "Hôtel de Booking.com"; $tr = 1; break;
case "La stanza di Booking.com":  		$messaggio = "La chambre de Booking.com"; $tr = 1; break;
case "con la tariffa":  			$messaggio = "avec le tarif"; $tr = 1; break;
case "corrisponde alla tariffa di hoteldruid":	$messaggio = "correspond au tarif de Hoteldruid"; $tr = 1; break;
case "<div style=\"display: inline; color: red;\">Attenzione</div>: tariffe e disponibilità su Booking.com verranno<br> sovrascritte con quelle di hoteldruid":	$messaggio = "<div style=\"display: inline; color: red;\">Attention</div>: les tarifs et disponibilités sur Booking.com seront<br> écrasées avec celles de Hoteldruid"; $tr = 1; break;
case "Modifica l'interconnessione":  		$messaggio = "Modifier l'interconnexion"; $tr = 1; break;
case "Si può assegnare una unica tariffa di hoteldruid ad ogni combinazione di stanza e tariffa di Booking.com":	$messaggio = "Vous pouvez affecter un seul tarif de Hoteldruid à chaque combinaison de chambre et de tarif de Booking.com"; $tr = 1; break;
case "Non è stata apportata nessuna modifica":	$messaggio = "Rien n'a été modifié"; $tr = 1; break;
case "Interconnessione con Booking.com aggiornata":	$messaggio = "L'interconnexion avec Booking.com a été mise à jour"; $tr = 1; break;
case "Nome utente xml di Booking.com":  	$messaggio = "Utilisateur Xml de Booking.com"; $tr = 1; break;
case "Password xml di Booking.com":  		$messaggio = "Mot de passe Xml de Booking.com"; $tr = 1; break;
case "Crea l'interconnessione":  		$messaggio = "Créer interconnexion"; $tr = 1; break;
case "Cancella l'interconnessione":  		$messaggio = "Supprimer interconnexion"; $tr = 1; break;
case "Interconnessione con Booking.com cancellata":	$messaggio = "Interconnexion avec Booking.com supprimée"; $tr = 1; break;
case "Inviare i messaggi a":  			$messaggio = "Send messages to"; $tr = 1; break;
case "Aggiorna manualmente le prenotazioni da Booking.com dal":	$messaggio = "Manually update reservations from Booking.com from"; $tr = 1; break;
case "Aggiorna":  				$messaggio = "Update"; $tr = 1; break;
case "tutti":  					$messaggio = "all"; $tr = 1; break;
case "Origine delle prenotazioni":  		$messaggio = "Reservations origin"; $tr = 1; break;
case "Salvare i dati della carta di credito nel commento del cliente?":	$messaggio = "Save credit card data in client's comment?"; $tr = 1; break;
case "SI":  					$messaggio = "YES"; $tr = 1; break;
case "NO":  					$messaggio = "NO"; $tr = 1; break;
case "Chiudere i periodi senza più disponibilità?":	$messaggio = "Close periods without availability?"; $tr = 1; break;
case "Tariffa opzionale per uso singola":  	$messaggio = "Optional rate for single use"; $tr = 1; break;
case "Provare ad inserire prenotazioni multiple in appartamenti vicini?":	$messaggio = "Try to insert multiple reservations in nearby rooms?"; $tr = 1; break;
case "Utente per le date da chiudere in arrivo e partenza":	$messaggio = "User for dates to be closed on arrival and departure"; $tr = 1; break;
case "AVVISO":  				$messaggio = "WARNING"; $tr = 1; break;
case "le tariffe per persona non sono supportate da":	$messaggio = "per person rates not supported by"; $tr = 1; break;
case "tariffa non aggiornata in remoto":  	$messaggio = "rate not updated remotely"; $tr = 1; break;
case "Utente che inserisce le prenotazioni":  	$messaggio = "User that inserts reservations"; $tr = 1; break;
case "Aggiornare la disponibilità quando si ricevono prenotazioni?":	$messaggio = "Update availability when reservations are received?"; $tr = 1; break;
case "aiuta ad evitare l'overbooking quando si ha":	$messaggio = "helps avoiding overbooking when you have"; $tr = 1; break;
case "in più tariffe con la regola 2, ma non lo evita del tutto":	$messaggio = "in different rates with rule 2, but doesn't avoid it completely"; $tr = 1; break;
case "Aggiorna manualmente tutti i prezzi e la disponibilità":	$messaggio = "Manually update all prices and availability"; $tr = 1; break;
case "Inviare una copia all'indirizzo email":	$messaggio = "Send a copy to email address"; $tr = 1; break;
case "prezzi e disponibilità":  		$messaggio = "prices and availability"; $tr = 1; break;
case "solo prezzi":  				$messaggio = "only prices"; $tr = 1; break;
case "Attenzione":  				$messaggio = "Warning"; $tr = 1; break;
case "c'è rischio di overbooking perchè alcune unità":	$messaggio = "there is a risk of overbooking because some units"; $tr = 1; break;
case "sono collegate con la regola 2 a diverse tariffe attivate per la disponibilità":	$messaggio = "are connected with rule 2 to different rates used for availability"; $tr = 1; break;
case "Hotel ID su Booking.com":  		$messaggio = "Hotel ID on Booking.com"; $tr = 1; break;
case "Nuova password":  			$messaggio = "New password"; $tr = 1; break;
case "Importare il prezzo della prenotazione quando non coincide con quello calcolato da hoteldruid?":	$messaggio = "Import reservation price when it don't matches the one calculated by hoteldruid?"; $tr = 1; break;
case "solo lettura":  				$messaggio = "read only"; $tr = 1; break;
case "solo disponibilità":  			$messaggio = "only availability"; $tr = 1; break;
case "ci sono combinazioni di camere/tariffe di booking.com non collegate a tariffe di hoteldruid, c'è il rischio di non poter scaricare alcune prenotazioni":	$messaggio = "there are combinations of rooms/rates from booking.com that are not connected to hoteldruid rates, there is the risk of not being able to download some reservations"; $tr = 1; break;
case "Inviare restrizioni (chiusura, permanenza minima, ecc.) per tariffe in sola lettura?":	$messaggio = "Send restrictions (closures, minimum stay, etc.) for read only rates?"; $tr = 1; break;
case "Considerare le prenotazioni scaricate come confermate?":	$messaggio = "Consider downloaded reservations as confirmed?"; $tr = 1; break;
case "Modifica le date":  			$messaggio = "Modify dates"; $tr = 1; break;
case "Per attivare la connessione xml con booking.com dovete accedere al vostro account su booking.com, nella sezione \"channel manager\", e mandare la richiesta di attivazione selezionando come provider \"digitaldruid\" (ID 68)":	$messaggio = "To activate the xml connection with booking.com you have to access your account on booking.com and, in \"channel manager\" section, send the request for activation selecting \"digitaldruid\" (ID 68) as your provider"; $tr = 1; break;
case "Scarica tutte le prenotazioni attuali e future":	$messaggio = "Download all current and future reservations"; $tr = 1; break;
case "continuando verranno scaricate le informazioni basiche di tutte le prenotazioni attuali e future presenti su Booking.com, comprese le prenotazioni arrivate prima dell'attivazione della connessione":	$messaggio = "by continuing the basic information of all current and future reservations on Booking.com  will be downloaded, including the reservations made before the activation of the connection"; $tr = 1; break;
case "Se alcune di queste prenotazioni sono già state inserite <em>manualmente</em> su hoteldruid allora verranno inserite di nuovo, dando luogo <em>erroneamente</em> ad una <b>doppia prenotazione</b> per ognuna di esse":	$messaggio = "If some of these reservations have already been inserted <em>manually</em> on hoteldruid then they will be inserted again, causing <em>erroneously</em> a <b>double reservation</b> for each one of them"; $tr = 1; break;
case "Se invece ci sono solo prenotazioni già scaricate dall'interconnessione con booking.com queste non verranno scaricate di nuovo":	$messaggio = "If, however, there are only reservations already downloaded from the interconnection with booking.com then these reservations will not be downloaded again"; $tr = 1; break;
case "massimo":  				$messaggio = "maximum"; $tr = 1; break;
case "persone aggiuntive":  			$messaggio = "extra persons"; $tr = 1; break;
case "persona aggiuntiva":  			$messaggio = "extra person"; $tr = 1; break;
case "Costo opzionale per persone aggiuntive":	$messaggio = "Optional cost for extra people"; $tr = 1; break;
case "inviare solo le persone di base":  	$messaggio = "send only basic people"; $tr = 1; break;
case "non inviare":  				$messaggio = "don't send"; $tr = 1; break;
case "persone di base corrispondenti al prezzo inviato":	$messaggio = "basic people corresponding to the price sent"; $tr = 1; break;
case "":  				$messaggio = ""; $tr = 1; break;
case "":  				$messaggio = ""; $tr = 1; break;

} # fine switch ($messaggio)

?>

==> hoteldruid-mod-fr_3.0.8-1.tar.gz: fr/modi_boo.php <==
<?php

switch ($messaggio) {

case "Hotel di Booking.com":  			$messaggio = "Hôtel de Booking.com"; $tr = 1; break;
case "La stanza di Booking.com":  		$messaggio = "La chambre de Booking.com"; $tr = 1; break;
case "con la tariffa":  			$messaggio = "avec le tarif"; $tr = 1; break;
case "corrisponde alla tariffa di hoteldruid":	$messaggio = "correspond au tarif de Hoteldruid"; $tr = 1; break;
case "<div style=\"display: inline; color: red;\">Attenzione</div>: tariffe e disponibilità su Booking.com verranno<br> sovrascritte con quelle di hoteldruid":	$messaggio = "<div style=\"display: inline; color: red;\">Attention</div>: les tarifs et disponibilités sur Booking.com seront<br> écrasées avec celles de Hoteldruid"; $tr = 1; break;
case "Modifica l'interconnessione":  		$messaggio = "Modifier l'interconnexion"; $tr = 1; break;
case "Si può assegnare una unica tariffa di hoteldruid ad ogni combinazione di stanza e tariffa di Booking.com":	$messaggio = "Vous pouvez affecter un seul tarif de Hoteldruid à chaque combinaison de chambre et de tarif de Booking.com"; $tr = 1; break;
case "Non è stata apportata nessuna modifica":	$messaggio = "Rien n'a été modifié"; $tr = 1; break;
case "Interconnessione con Booking.com aggiornata":	$messaggio = "L'interconnexion avec Booking.com a été mise à jour"; $tr = 1; break;
case "Nome utente xml di Booking.com":  	$messaggio = "Utilisateur Xml de Booking.com"; $tr = 1; break;
case "Password xml di Booking.com":  		$messaggio = "Mot de passe Xml de Booking.com"; $tr = 1; break;
case "Crea l'interconnessione":  		$messaggio = "Créer interconnexion"; $tr = 1; break;
case "Cancella l'interconnessione":  		$messaggio = "Supprimer interconnexion"; $tr = 1; break;
case "Interconnessione con Booking.com cancellata":	$messaggio = "Interconnexion avec Booking.com supprimée"; $tr = 1; break;
case "Inviare i messaggi a":  			$messaggio = "Send messages to"; $tr = 1; break;
case "Aggiorna manualmente le prenotazioni da Booking.com dal":	$messaggio = "Manually update reservations from Booking.com from"; $tr = 1; break;
case "Aggiorna":  				$messaggio = "Update"; $tr = 1; break;
case "tutti":  					$messaggio = "all"; $tr = 1; break;
case "Origine delle prenotazioni":  		$messaggio = "Reservations origin"; $tr = 1; break;
case "Salvare i dati della carta di credito nel commento del cliente?":	$messaggio = "Save credit card data in client's comment?"; $tr = 1; break;
case "SI":  					$messaggio = "YES"; $tr = 1; break;
case "NO":  					$messaggio = "NO"; $tr = 1; break;
case "Chiudere i periodi senza più disponibilità?":	$messaggio = "Close periods without availability?"; $tr = 1; break;
case "Tariffa opzionale per uso singola":  	$messaggio = "Optional rate for single use"; $tr = 1; break;
case "Provare ad inserire prenotazioni multiple in appartamenti vicini?":	$messaggio = "Try to insert multiple reservations in nearby rooms?"; $tr = 1; break;
case "Utente per le date da chiudere in arrivo e partenza":	$messaggio = "User for dates to be closed on arrival and departure"; $tr = 1; break;
case "AVVISO":  				$messaggio = "WARNING"; $tr = 1; break;
case "le tariffe per persona non sono supportate da":	$messaggio = "per person rates not supported by"; $tr = 1; break;
case "tariffa non aggiornata in remoto":  	$messaggio = "rate not updated remotely"; $tr = 1; break;
case "Utente che inserisce le prenotazioni":  	$messaggio = "User that inserts reservations"; $tr = 1; break;
case "Aggiornare la disponibilità quando si ricevono prenotazioni?":	$messaggio = "Update availability when reservations are received?"; $tr = 1; break;
case "aiuta ad evitare l'overbooking quando si ha":	$messaggio = "helps avoiding overbooking when you have"; $tr = 1; break;
case "in più tariffe con la regola 2, ma non lo evita del tutto":	$messaggio = "in different rates with rule 2, but doesn't avoid it completely"; $tr = 1; break;
case "Aggiorna manualmente tutti i prezzi e la disponibilità":	$messaggio = "Manually update all prices and availability"; $tr = 1; break;
case "Inviare una copia all'indirizzo email":	$messaggio = "Send a copy to email address"; $tr = 1; break;
case "prezzi e disponibilità":  		$messaggio = "prices and availability"; $tr = 1; break;
case "solo prezzi":  				$messaggio = "only prices"; $tr = 1; break;
case "Attenzione":  				$messaggio = "Warning"; $tr = 1; break;
case "c'è rischio di overbooking perchè alcune unità":	$messaggio = "there is a risk of overbooking because some units"; $tr = 1; break;
case "sono collegate con la regola 2 a diverse tariffe attivate per la disponibilità":	$messaggio = "are connected with rule 2 to different rates used for availability"; $tr = 1; break;
case "Hotel ID su Booking.com":  		$messaggio = "Hotel ID on Booking.com"; $tr = 1; break;
case "Nuova password":  			$messaggio = "New password"; $tr = 1; break;
case "Importare il prezzo della prenotazione quando non coincide con quello calcolato da hoteldruid?":	$messaggio = "Import reservation price when it don't matches the one calculated by hoteldruid?"; $tr = 1; break;
case "solo lettura":  				$messaggio = "read only"; $tr = 1; break;
case "solo disponibilità":  			$messaggio = "only availability"; $tr = 1; break;
case "ci sono combinazioni di camere/tariffe di booking.com non collegate a tariffe di hoteldruid, c'è il rischio di non poter scaricare alcune prenotazioni":	$messaggio = "there are combinations of rooms/rates from booking.com that are not connected to hoteldruid rates, there is the risk of not being able to download some reservations"; $tr = 1; break;
case "Inviare restrizioni (chiusura, permanenza minima, ecc.) per tariffe in sola lettura?":	$messaggio = "Send restrictions (closures, minimum stay, etc.) for read only rates?"; $tr = 1; break;
case "Considerare le prenotazioni scaricate come confermate?":	$messaggio = "Consider downloaded reservations as confirmed?"; $tr = 1; break;
case "Modifica le date":  			$messaggio = "Modify dates"; $tr = 1; break;
case "Per attivare la connessione xml con booking.com dovete accedere al vostro account su booking.com, nella sezione \"channel manager\", e mandare la richiesta di attivazione selezionando come provider \"digitaldruid\" (ID 68)":	$messaggio = "To activate the xml connection with booking.com you have to access your account on booking.com and, in \"channel manager\" section, send the request for activation selecting \"digitaldruid\" (ID 68) as your provider"; $tr = 1; break;
case "Scarica tutte le prenotazioni attuali e future":	$messaggio = "Download all current and future reservations"; $tr = 1; break;
case "continuando verranno scaricate le informazioni basiche di tutte le prenotazioni attuali e future presenti su Booking.com, comprese le prenotazioni arrivate prima dell'attivazione della connessione":	$messaggio = "by continuing the basic information of all current and future reservations on Booking.com  will be downloaded, including the reservations made before the activation of the connection"; $tr = 1; break;
case "Se alcune di queste prenotazioni sono già state inserite <em>manualmente</em> su hoteldruid allora verranno inserite di nuovo, dando luogo <em>erroneamente</em> ad una <b>doppia prenotazione</b> per ognuna di esse":	$messaggio = "If some of these reservations have already been inserted <em>manually</em> on hoteldruid then they will be inserted again, causing <em>erroneously</em> a <b>(float) reservation</b> for each one of them"; $tr = 1; break;
case "Se invece ci sono solo prenotazioni già scaricate dall'interconnessione con booking.com queste non verranno scaricate di nuovo":	$messaggio = "If, however, there are only reservations already downloaded from the interconnection with booking.com then these reservations will not be downloaded again"; $tr = 1; break;
case "massimo":  				$messaggio = "maximum"; $tr = 1; break;
case "persone aggiuntive":  			$messaggio = "extra persons"; $tr = 1; break;
case "persona aggiuntiva":  			$messaggio = "extra person"; $tr = 1; break;
case "Costo opzionale per persone aggiuntive":	$messaggio = "Optional cost for extra people"; $tr = 1; break;
case "inviare solo le persone di base":  	$messaggio = "send only basic people"; $tr = 1; break;
case "non inviare":  				$messaggio = "don't send"; $tr = 1; break;
case "persone di base corrispondenti al prezzo inviato":	$messaggio = "basic people corresponding to the price sent"; $tr = 1; break;
case "le credenziali di accesso inserite sono errate":	$messaggio = "the entered credentials are incorrect"; $tr = 1; break;
case "Errore":  				$messaggio = "Error"; $tr = 1; break;
case "Le tariffe per uso singola sono abilitate su booking.com?":	$messaggio = "Are rates for single use enabled on booking.com?"; $tr = 1; break;
case "Cancellare le prenotazioni in modo permanete?":	$messaggio = "Delete reservations permanently?"; $tr = 1; break;
case "Aggiungere commenti e richieste extra al":	$messaggio = "Add comments and extra requests to"; $tr = 1; break;
case "Commento della prenotazione":  		$messaggio = "Reservation comment"; $tr = 1; break;
case "":  				$messaggio = ""; $tr = 1; break;
case "":  				$messaggio = ""; $tr = 1; break;

} # fine switch ($messaggio)

?>
